#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 svg-builder
version:              0.1.1
visibility:           public
id:                   svg-builder-0.1.1-Cvzh2bD8an83V5RxzBabYf
key:                  svg-builder-0.1.1-Cvzh2bD8an83V5RxzBabYf
license:              BSD-3-Clause
copyright:            2016 Jeffrey Rosenbluth
maintainer:           jeffrey.rosenbluth@gmail.com
author:               Jeffrey Rosenbluth
homepage:             https://github.com/diagrams/svg-builder.git
synopsis:             DSL for building SVG.
description:          Fast, easy to write SVG.
category:             Graphics
abi:                  e6f74a1d75c5ccc9088cca0304bc0b56
exposed:              True
exposed-modules:
    Graphics.Svg Graphics.Svg.Attributes Graphics.Svg.Core
    Graphics.Svg.Elements Graphics.Svg.Path

import-dirs:          /usr/lib/ghc-9.6.6/site-local/svg-builder-0.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/svg-builder-0.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/svg-builder-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-svg-builder
hs-libraries:         HSsvg-builder-0.1.1-Cvzh2bD8an83V5RxzBabYf
depends:
    base-4.18.2.1 blaze-builder-0.4.4.1-4hsr4c7kSq49yqSn7bkiqU
    bytestring-0.11.5.3 hashable-1.4.7.0-H7NkROSKCrjFQZGpvHIgO1
    text-2.0.2 unordered-containers-0.2.20.1-2pZfUb3hQF1KSawFItMd4V

haddock-interfaces:   /usr/share/doc/haskell-svg-builder/html/svg-builder.haddock
haddock-html:         /usr/share/doc/haskell-svg-builder/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

